[−][src]Struct rustfft::algorithm::Dft
Naive O(n^2 ) Discrete Fourier Transform implementation
This implementation is primarily used to test other FFT algorithms.
// Computes a naive DFT of size 123 use rustfft::algorithm::Dft; use rustfft::{Fft, FftDirection}; use rustfft::num_complex::Complex; let mut buffer = vec![Complex{ re: 0.0f32, im: 0.0f32 }; 123]; let dft = Dft::new(123, FftDirection::Forward); dft.process(&mut buffer);
Implementations
impl<T: FftNum> Dft<T>[src]
pub fn new(len: usize, direction: FftDirection) -> Self[src]
Preallocates necessary arrays and precomputes necessary data to efficiently compute Dft